==> activity-center-biz-1.0.2-20160701.054452-45-sources.jar: cn/com/duiba/activity/center/biz/entity/ngame/DuibaNgameEntity.java <==
package cn.com.duiba.activity.center.biz.entity.ngame;

import java.io.Serializable;
import java.util.Date;

public class DuibaNgameEntity implements Serializable{
	
	private Long id;
	private String title;
	private Integer gameStatus;
	private Integer creditsPrice;
	private Integer freeLimit;
	private String freeScope;
	private Integer limitCount;
	private String limitScope;
	private Long duibaGameBrickId;
	private String rule;
	private Integer shareScores;
	private String shareApp;
	private String banner;
	private String smallImage;
	private String whiteImage;
	private String logo;
	private Boolean isOpenPrize;
	private Integer switches;
	private Date autoOffDate;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;
	private String freeRule;
	/*奖项的json字符串*/
	private String optionsJson;
	//是否开启定向
	private Boolean openSpecify;
	//是否开启黑名单
	private Boolean openBlack;
	//免费
	private Boolean openFreeRule;
	//double
	private Double dCreditsPrice;
	
	private String recommendImage;

	public Integer getGameStatus() {
		return gameStatus;
	}
	public void setGameStatus(Integer gameStatus) {
		this.gameStatus = gameStatus;
	}
	public Long getDuibaGameBrickId() {
		return duibaGameBrickId;
	}
	public void setDuibaGameBrickId(Long duibaGameBrickId) {
		this.duibaGameBrickId = duibaGameBrickId;
	}
	public String getRule() {
		return rule;
	}
	public void setRule(String rule) {
		this.rule = rule;
	}
	public String getBanner() {
		return banner;
	}
	public void setBanner(String banner) {
		this.banner = banner;
	}
	public String getWhiteImage() {
		return whiteImage;
	}
	public void setWhiteImage(String whiteImage) {
		this.whiteImage = whiteImage;
	}
	public Double getdCreditsPrice() {
		return dCreditsPrice;
	}
	public void setdCreditsPrice(Double dCreditsPrice) {
		this.dCreditsPrice = dCreditsPrice;
	}
	public String getShareApp() {
		return shareApp;
	}
	public void setShareApp(String shareApp) {
		this.shareApp = shareApp;
	}
	public Boolean getOpenSpecify() {
		return openSpecify;
	}
	public void setOpenSpecify(Boolean openSpecify) {
		this.openSpecify = openSpecify;
	}
	public Boolean getOpenBlack() {
		return openBlack;
	}
	public void setOpenBlack(Boolean openBlack) {
		this.openBlack = openBlack;
	}
	public String getOptionsJson() {
		return optionsJson;
	}
	public void setOptionsJson(String optionsJson) {
		this.optionsJson = optionsJson;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public Integer getCreditsPrice() {
		return creditsPrice;
	}
	public void setCreditsPrice(Integer creditsPrice) {
		this.creditsPrice = creditsPrice;
	}
	public Integer getFreeLimit() {
		return freeLimit;
	}
	public void setFreeLimit(Integer freeLimit) {
		this.freeLimit = freeLimit;
	}
	public String getFreeScope() {
		return freeScope;
	}
	public void setFreeScope(String freeScope) {
		this.freeScope = freeScope;
	}
	public Integer getLimitCount() {
		return limitCount;
	}
	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}
	public String getLimitScope() {
		return limitScope;
	}
	public void setLimitScope(String limitScope) {
		this.limitScope = limitScope;
	}
	public Integer getShareScores() {
		return shareScores;
	}
	public void setShareScores(Integer shareScores) {
		this.shareScores = shareScores;
	}
	public String getSmallImage() {
		return smallImage;
	}
	public void setSmallImage(String smallImage) {
		this.smallImage = smallImage;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public Boolean getIsOpenPrize() {
		return isOpenPrize;
	}
	public void setIsOpenPrize(Boolean isOpenPrize) {
		this.isOpenPrize = isOpenPrize;
	}
	public Integer getSwitches() {
		return switches;
	}
	public void setSwitches(Integer switches) {
		this.switches = switches;
	}
	public Date getAutoOffDate() {
		return autoOffDate;
	}
	public void setAutoOffDate(Date autoOffDate) {
		this.autoOffDate = autoOffDate;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	
	public void openSwitch(int s) {
		int v = 1 << s;
		switches = switches | v;
	}

	public void closeSwitch(int s) {
		int v = 1 << s;
		v = ~v;
		switches = switches & v;
	}

	public boolean isOpenSwitch(int s) {
		int v = 1 << s;
		int ret = switches & v;
		return ret != 0;
	}

	public String getFreeRule() {
		return freeRule;
	}

	public void setFreeRule(String freeRule) {
		this.freeRule = freeRule;
	}
	public Boolean getOpenFreeRule() {
		return openFreeRule;
	}
	public void setOpenFreeRule(Boolean openFreeRule) {
		this.openFreeRule = openFreeRule;
	}
	public String getRecommendImage() {
		return recommendImage;
	}
	public void setRecommendImage(String recommendImage) {
		this.recommendImage = recommendImage;
	}
}

==> activity-center-biz-1.0.2-20160706.034119-56-sources.jar: cn/com/duiba/activity/center/biz/entity/ngame/DuibaNgameEntity.java <==
package cn.com.duiba.activity.center.biz.entity.ngame;

import java.io.Serializable;
import java.util.Date;

public class DuibaNgameEntity implements Serializable{
	
	private Long id;
	private String title;
	private Integer gameStatus;
	private Integer creditsPrice;
	private Integer freeLimit;
	private String freeScope;
	private Integer limitCount;
	private String limitScope;
	private Long duibaGameBrickId;
	private String rule;
	private Integer shareScores;
	private String shareApp;
	private String banner;
	private String smallImage;
	private String whiteImage;
	private String logo;
	private Boolean isOpenPrize;
	private Integer switches;
	private Date autoOffDate;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;
	private String freeRule;
	/*奖项的json字符串*/
	private String optionsJson;
	//是否开启定向
	private Boolean openSpecify;
	//是否开启黑名单
	private Boolean openBlack;
	//免费
	private Boolean openFreeRule;
	//double
	private Double dCreditsPrice;
	
	private String recommendImage;
	private Integer unopen;

	private Long activityCategoryId; //活动归类 --徐恒飞
	private Boolean anticheatLimit;

	public Boolean getAnticheatLimit() {
		return anticheatLimit;
	}
	public void setAnticheatLimit(Boolean anticheatLimit) {
		this.anticheatLimit = anticheatLimit;
	}
	
	public Integer getGameStatus() {
		return gameStatus;
	}
	public void setGameStatus(Integer gameStatus) {
		this.gameStatus = gameStatus;
	}
	public Long getDuibaGameBrickId() {
		return duibaGameBrickId;
	}
	public void setDuibaGameBrickId(Long duibaGameBrickId) {
		this.duibaGameBrickId = duibaGameBrickId;
	}
	public String getRule() {
		return rule;
	}
	public void setRule(String rule) {
		this.rule = rule;
	}
	public String getBanner() {
		return banner;
	}
	public void setBanner(String banner) {
		this.banner = banner;
	}
	public String getWhiteImage() {
		return whiteImage;
	}
	public void setWhiteImage(String whiteImage) {
		this.whiteImage = whiteImage;
	}
	public Double getdCreditsPrice() {
		return dCreditsPrice;
	}
	public void setdCreditsPrice(Double dCreditsPrice) {
		this.dCreditsPrice = dCreditsPrice;
	}
	public String getShareApp() {
		return shareApp;
	}
	public void setShareApp(String shareApp) {
		this.shareApp = shareApp;
	}
	public Boolean getOpenSpecify() {
		return openSpecify;
	}
	public void setOpenSpecify(Boolean openSpecify) {
		this.openSpecify = openSpecify;
	}
	public Boolean getOpenBlack() {
		return openBlack;
	}
	public void setOpenBlack(Boolean openBlack) {
		this.openBlack = openBlack;
	}
	public String getOptionsJson() {
		return optionsJson;
	}
	public void setOptionsJson(String optionsJson) {
		this.optionsJson = optionsJson;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public Integer getCreditsPrice() {
		return creditsPrice;
	}
	public void setCreditsPrice(Integer creditsPrice) {
		this.creditsPrice = creditsPrice;
	}
	public Integer getFreeLimit() {
		return freeLimit;
	}
	public void setFreeLimit(Integer freeLimit) {
		this.freeLimit = freeLimit;
	}
	public String getFreeScope() {
		return freeScope;
	}
	public void setFreeScope(String freeScope) {
		this.freeScope = freeScope;
	}
	public Integer getLimitCount() {
		return limitCount;
	}
	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}
	public String getLimitScope() {
		return limitScope;
	}
	public void setLimitScope(String limitScope) {
		this.limitScope = limitScope;
	}
	public Integer getShareScores() {
		return shareScores;
	}
	public void setShareScores(Integer shareScores) {
		this.shareScores = shareScores;
	}
	public String getSmallImage() {
		return smallImage;
	}
	public void setSmallImage(String smallImage) {
		this.smallImage = smallImage;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public Boolean getIsOpenPrize() {
		return isOpenPrize;
	}
	public void setIsOpenPrize(Boolean isOpenPrize) {
		this.isOpenPrize = isOpenPrize;
	}
	public Integer getSwitches() {
		return switches;
	}
	public void setSwitches(Integer switches) {
		this.switches = switches;
	}
	public Date getAutoOffDate() {
		return autoOffDate;
	}
	public void setAutoOffDate(Date autoOffDate) {
		this.autoOffDate = autoOffDate;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	
	public void openSwitch(int s) {
		int v = 1 << s;
		switches = switches | v;
	}

	public void closeSwitch(int s) {
		int v = 1 << s;
		v = ~v;
		switches = switches & v;
	}

	public boolean isOpenSwitch(int s) {
		int v = 1 << s;
		int ret = switches & v;
		return ret != 0;
	}

	public String getFreeRule() {
		return freeRule;
	}

	public void setFreeRule(String freeRule) {
		this.freeRule = freeRule;
	}
	public Boolean getOpenFreeRule() {
		return openFreeRule;
	}
	public void setOpenFreeRule(Boolean openFreeRule) {
		this.openFreeRule = openFreeRule;
	}
	public String getRecommendImage() {
		return recommendImage;
	}
	public void setRecommendImage(String recommendImage) {
		this.recommendImage = recommendImage;
	}

    public Long getActivityCategoryId() {
        return activityCategoryId;
    }

    public void setActivityCategoryId(Long activityCategoryId) {
        this.activityCategoryId = activityCategoryId;
    }
    
    public Integer getUnopen() {
        return unopen;
    }
    
    public void setUnopen(Integer unopen) {
        this.unopen = unopen;
    }
}
